==> elasticsearch-dsl-0.1.11.crate: elasticsearch-dsl-0.1.11/src/search/aggregations/metrics/sum_aggregation.rs <==
use crate::search::*;
use crate::util::*;

/// A `single-value` metrics aggregation that sums up numeric values that are extracted from the
/// aggregated documents. These values can be extracted either from specific numeric or histogram fields.
///
/// <https://www.elastic.co/guide/en/elasticsearch/reference/current/search-aggregations-metrics-sum-aggregation.html>
#[derive(Debug, Clone, Serialize, PartialEq)]
pub struct SumAggregation {
    #[serde(skip_serializing)]
    pub(crate) name: String,
    sum: SumAggregationInner,
}

#[derive(Debug, Clone, Serialize, PartialEq)]
struct SumAggregationInner {
    field: String,

    #[serde(skip_serializing_if = "ShouldSkip::should_skip")]
    missing: Option<Number>,
}

impl Aggregation {
    /// Creates an instance of [`SumAggregation`]
    ///
    /// - `name` - name of the aggregation
    /// - `field` - field to aggregate
    pub fn sum(name: impl Into<String>, field: impl Into<String>) -> SumAggregation {
        SumAggregation {
            name: name.into(),
            sum: SumAggregationInner {
                field: field.into(),
                missing: None,
            },
        }
    }
}

impl SumAggregation {
    /// The `missing` parameter defines how documents that are missing a value should be treated. By
    /// default documents missing the value will be ignored but it is also possible to treat them
    /// as if they had a value.
    pub fn missing(mut self, missing: impl Into<Number>) -> Self {
        self.sum.missing = Some(missing.into());
        self
    }
}

#[cfg(test)]
mod tests {
    use super::*;

    test_serialization! {
        with_required_fields(
            Aggregation::sum("test_sum", "test_field"),
            json!({ "sum": { "field": "test_field" } })
        );

        with_all_fields(
            Aggregation::sum("test_sum", "test_field")
                .missing(100.1),
            json!({
                "sum": {
                    "field": "test_field",
                    "missing": 100.1
                }
            })
        );
    }
}

==> elasticsearch-dsl-0.3.4.crate: elasticsearch-dsl-0.3.4/src/search/aggregations/metrics/sum_aggregation.rs <==
use crate::search::*;
use crate::util::*;

/// A `single-value` metrics aggregation that sums up numeric values that are extracted from the
/// aggregated documents. These values can be extracted either from specific numeric or histogram fields.
///
/// <https://www.elastic.co/guide/en/elasticsearch/reference/current/search-aggregations-metrics-sum-aggregation.html>
#[derive(Debug, Clone, Serialize, PartialEq)]
pub struct SumAggregation {
    sum: SumAggregationInner,
}

#[derive(Debug, Clone, Serialize, PartialEq)]
struct SumAggregationInner {
    field: String,

    #[serde(skip_serializing_if = "ShouldSkip::should_skip")]
    missing: Option<Number>,
}

impl Aggregation {
    /// Creates an instance of [`SumAggregation`]
    ///
    /// - `field` - field to aggregate
    pub fn sum(field: impl Into<String>) -> SumAggregation {
        SumAggregation {
            sum: SumAggregationInner {
                field: field.into(),
                missing: None,
            },
        }
    }
}

impl SumAggregation {
    /// The `missing` parameter defines how documents that are missing a value should be treated. By
    /// default documents missing the value will be ignored but it is also possible to treat them
    /// as if they had a value.
    pub fn missing(mut self, missing: impl Into<Number>) -> Self {
        self.sum.missing = Some(missing.into());
        self
    }
}

#[cfg(test)]
mod tests {
    use super::*;

    #[test]
    fn serialization() {
        assert_serialize(
            Aggregation::sum("test_field"),
            json!({ "sum": { "field": "test_field" } }),
        );

        assert_serialize(
            Aggregation::sum("test_field").missing(100.1),
            json!({
                "sum": {
                    "field": "test_field",
                    "missing": 100.1
                }
            }),
        );
    }
}
